@@ -503,25 +503,25 @@ class DataVars(object):
         return valueVar.encode("UTF-8")
 
     def GetRemoteInfo(self, envFile):
-        """Получение информационных переменных
-
-        из файла envFile"""
+        """
+        Get information variables from server env
+        """
         optionsInfo = {}
-        # получить объект настроенный на ini
+        # get ini object
         config = iniParser(envFile)
-        # получаем все секции из конфигурационного файла
+        # get all section from ini object
         allsect = config.getAllSectionNames()
         if allsect:
-            # Секция (название сервиса)
+            # sectin - service name
             for section in allsect:
                 allvars = config.getAreaVars(section)
                 if allvars == False:
                     return False
-                # Опции сервиса
+                # get service option
                 options = {}
                 for varName, value in allvars.items():
                     varName = varName.encode("UTF-8")
-                    value=convertStrListDict(value.encode("UTF-8"))
+                    value=value.encode("UTF-8")
                     options[varName] = value
                 if options:
                     optionsInfo[section] = options
