@@ -841,8 +841,8 @@ def checkDigestFile(digestfile):
 def getFilesCount(directory):
     """Get files count from directory"""
     if path.exists(directory):
-        return len(reduce(lambda x,y:x+y,map(lambda x:x[1]+x[2],
-                          os.walk(directory)),[]))
+        return reduce(lambda x,y:x+len(y[1])+len(y[2]),
+               os.walk(directory),0)
     return 0
 
 def listDirectory(directory,fullPath=False):
@@ -870,8 +870,8 @@ def getDistfilesVideo(prefix="/"):
     """Get video drivers from distfiles"""
     distFiles = path.join(prefix,"usr/portage/distfiles")
     return list(set(
-           map(lambda x:'fglrx' if x.startswith('ati-driver') else "nvidia",
-           filter(lambda x:x.startswith('ati-driver-installer') or
+           map(lambda x:'fglrx' if "amd" in x else "nvidia",
+           filter(lambda x:"amd" in x or
                            x.startswith('NVIDIA-Linux'),
            listDirectory(distFiles)))))
 
@@ -934,7 +934,7 @@ def getProgPath(progname):
     env = {"LANG":"C"}
     env.update(os.environ.items() + [("PATH",getpathenv())] +\
                env.items())
-    res = runOsCommand("which %s"%progname,env_dict=env)
+    res = runOsCommand("which %s"%baseprogname,env_dict=env)
     if res[0] == 0:
         return res[1][0].strip()
     elif path.isabs(progname) and path.exists(progname):
@@ -1047,6 +1047,12 @@ def getSquashList():
     if not usesSquashFs:
         return ["gzip"]
     else:
+        pkgInfo = getPkgInstalled('sys-fs/squashfs-tools')
+        if pkgInfo and pkgInfo[0]['PV']:
+            pkgVer = getTupleVersion(pkgInfo[0]['PV'])
+            gzipVer = getTupleVersion('4.2')
+            if pkgVer >= gzipVer:
+                usesSquashFs.append('gzip')
         return map(lambda x:{"lzma":"xz"}.get(x,x),
                list(set(usesSquashFs) & wantMethod))
 
@@ -1439,3 +1445,17 @@ def tarLinks(rootpath,archpath,skip=[]):
         removeDirs)
     tar.close()
     return links
+
+def countFiles(dirpath,onefilesystem=True):
+    """
+    Count files in dirpath
+    """
+    num = 1
+    for dirpath,dirnames,filenames in os.walk(dirpath):
+        num += len(set(dirnames) | set(filenames))
+        if onefilesystem:
+            mountDirs = filter(lambda x:path.ismount(path.join(dirpath,x)),
+                        dirnames)
+            for dirname in mountDirs:
+                dirnames.remove(dirname)
+    return num
